Dtmf class
Dtmf enables playing DTMF tones crossplatform
Constructors
- Dtmf()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
playTone(
{required String digits, int? durationMs, double? samplingRate, double? volume}) → Future< bool?> -
Plays the DTMF Tones Associated with the
digits. Each tone is played for the durationdurationMsin milliseconds at the specified volume. If no volume is specified, the system default is used. Volume value should be between 0 and 1. Returns true if tone played successfully