Tone class

Constructors

Tone({dynamic context, int? frequency1, int? frequency2})
constructor

Properties

context ↔ dynamic
getter/setter pair
frequency1 ↔ int?
getter/setter pair
frequency2 ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → void
start plays the tone
stop() → void
stop terminates playing the tone
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited